<!--- DO NOT EDIT THIS FILE. Generated by README.py-->
# Poisson

```
./run
```
Output directory `out_poisson`:
* [`train.log`](https://cselab.github.io/odil/examples/out_poisson/train.log)
* [`train.csv`](https://cselab.github.io/odil/examples/out_poisson/train.csv)
* [`train.png`](https://cselab.github.io/odil/examples/out_poisson/train.png)  
  <img src="https://cselab.github.io/odil/examples/out_poisson/train.png" height=200>
* [`field.png`](https://cselab.github.io/odil/examples/out_poisson/field.png)  
  <img src="https://cselab.github.io/odil/examples/out_poisson/field.png" height=200>
